package com.hc.business.mapper;

import com.hc.business.dto.TypeCourseDto;
import com.hc.business.model.Course;
import org.springframework.stereotype.Repository;
import com.hc.core.utils.mapper.Mapper;

import java.util.List;

/**
 * 课程表(Course)表数据库访问层
 *
 * @author java
 * @since 2020-11-09 10:04:45
 */

@Repository
public interface CourseMapper extends Mapper<Course> {

    /**
     * 查询所有的课程分类id
     *
     * @param typeId 分类id
     * @return 实例对象数组
     */
    List<TypeCourseDto> queryByTypeId(Integer typeId);

    /**
     * 依据老师名称获取课程
     *
     * @param name 老师名称
     * @return 实例对象数组
     */
    List<Course> queryTeacherName(String name);

    /**
     * 依据课程名称获取课程
     *
     * @param name 课程名称
     * @return 实例对象数组
     */
    List<Course> queryCourseName(String name);

    /**
     * 获取全部课程
     *
     * @param valid 是否上下架
     * @return 实例对象数组
     */
    List<Course> queryAll(Integer valid);
}