package com.hc.business.service;

import com.github.pagehelper.PageInfo;
import com.hc.business.dto.ClassPrintDto;
import com.hc.business.model.ClassConfig;
import org.springframework.stereotype.Component;

import java.util.List;


/**
 * 班次表(ClassConfig)表服务接口
 *
 * @author java
 * @since 2020-11-19 16:12:31
 */

@Component
public interface ClassConfigService {

    /**
     * 通过ID查询单条数据
     *
     * @param classConfigId 主键
     * @return 实例对象
     */
    ClassConfig queryById(Integer classConfigId);

    /**
     * 新增数据
     *
     * @param classConfig 实例对象
     * @return 实例对象
     */
    ClassConfig insert(ClassConfig classConfig);

    /**
     * 修改数据
     *
     * @param classConfig 实例对象
     * @return 实例对象
     */
    ClassConfig update(ClassConfig classConfig);

    /**
     * 通过主键删除数据
     *
     * @param classConfigId 主键
     * @return 是否成功
     */
    boolean deleteById(Integer classConfigId);

    /**
     * 分页查询多条数据
     *
     * @param page 页码
     * @param size 查询条数
     * @return 对象列表
     */
    PageInfo queryAllByLimit(int page, int size);

    /**
     * 校验查询培训班
     *
     * @param valid 是否上线
     * @param page  页码
     * @param size  查询条数
     * @return 实例对象数组
     */
    PageInfo queryByValid(Integer valid, int page, int size);

    /**
     * 培训班名称查询培训班
     *
     * @param name 培训班名称
     * @return 实例对象数组
     */
    List<ClassConfig> queryByClassName(String name);

    /**
     * 地区id查询培训班
     *
     * @param areaId 地区id
     * @param page   页码
     * @param size   查询条数
     * @return 对象列表
     */
    PageInfo queryByAreaId(Integer areaId, int page, int size);


    /**
     * 学习时间查询培训班
     *
     * @param studyStartTime 学习开始时间
     * @param page           页码
     * @param size           查询条数
     * @return 对象列表
     */
    PageInfo queryByTime(Long studyStartTime, Integer page, Integer size);

    /**
     * 按照培训对象查询
     *
     * @param target 学习开始时间
     * @param page           页码
     * @param size           查询条数
     * @return 对象列表
     */
    PageInfo queryByTarget(String target, Integer page, Integer size);

    /**
     * 按照培训对象查询
     *
     * @param year 年度
     * @param page           页码
     * @param size           查询条数
     * @return 对象列表
     */
    PageInfo queryByYear(String year, Integer page, Integer size);


    /**
     * @Author
     * @Description 根据身份证查看可以打印的证书
     * @return
     **/
    List<ClassPrintDto> getPrintList(String cardId);
}