package com.hc.business.service;

import com.github.pagehelper.PageInfo;
import com.hc.business.model.UserInvoices;
import org.springframework.stereotype.Component;

import java.util.List;


/**
 * 用户发票表(UserInvoices)表服务接口
 *
 * @author java
 * @since 2020-12-02 10:50:36
 */

@Component
public interface UserInvoicesService {

    /**
     * 通过ID查询单条数据
     *
     * @param userInvoicesId 主键
     * @return 实例对象
     */
    UserInvoices queryById(Integer userInvoicesId);

    /**
     * 新增数据
     *
     * @param userInvoices 实例对象
     * @return 实例对象
     */
    UserInvoices insert(UserInvoices userInvoices);

    /**
     * 修改数据
     *
     * @param userInvoices 实例对象
     * @return 实例对象
     */
    UserInvoices update(UserInvoices userInvoices);

    /**
     * 通过主键删除数据
     *
     * @param userInvoicesId 主键
     * @return 是否成功
     */
    boolean deleteById(Integer userInvoicesId);

    /**
     * 分页查询多条数据
     *
     * @param page 页码
     * @param size 查询条数
     * @return 对象列表
     */
    PageInfo queryAllByLimit(int page, int size);

    /**
     * 获取用户的发票信息
     *
     * @param userId 用户id
     * @return 实例对象数组
     */
    List<UserInvoices> queryDetailByUserId(Integer userId);

    /**
     * 获取班次发票信息
     *
     * @param classId 班次id
     * @return 实例对象数组
     */
    List<UserInvoices> queryByClassId(Integer classId);

    /**
     * 获取班次发票信息
     *
     * @param orderId 班次id
     * @return 实例对象数组
     */
    List<UserInvoices> queryByOrderId(Integer orderId,Integer syncStatus);

    /**
     * 获取状态获取发票信息
     *
     * @param status 状态
     * @return 实例对象数组
     */
    List<UserInvoices> queryByStatus(Integer status);

    UserInvoices queryBySyncSerialNum(String syncSerialNum);

    /**
     * @Author ymnets
     * @Description 根据发票代码获取发票
     * @return com.hc.business.model.UserInvoices
     **/
    UserInvoices queryByFPCode(String fpCode);

    /**
     * @Author ymnets
     * @Description 根据订单号（诺诺订单号）
     *      * @return
     * @return com.hc.business.model.UserInvoices
     **/
    UserInvoices queryBySyncOrderNo(String syncOrderNo);

    PageInfo queryAllInvoices(int page, int size,String orderNo,Long begin,Long end);
}