package com.hc.business.service.impl;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.hc.business.mapper.CourseTypeMapper;
import com.hc.business.model.CourseType;
import com.hc.business.service.CourseTypeService;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;

import java.util.List;

/**
 * (CourseType)表服务实现类
 *
 * @author java
 * @since 2020-12-17 14:12:54
 */

@Service("courseTypeService")
public class CourseTypeServiceImpl implements CourseTypeService {

    private final CourseTypeMapper courseTypeMapper;

    public CourseTypeServiceImpl(CourseTypeMapper courseTypeMapper) {
        this.courseTypeMapper = courseTypeMapper;
    }

    /**
     * 通过ID查询单条数据
     *
     * @param courseTypeId 主键
     * @return 实例对象
     */
    @Override
    public CourseType queryById(Integer courseTypeId) {
        return this.courseTypeMapper.selectByPrimaryKey(courseTypeId);
    }

    /**
     * 新增数据
     *
     * @param courseType 实例对象
     * @return 实例对象
     */
    @Override
    public CourseType insert(CourseType courseType) {
        List<CourseType> courseTypes
                = this.courseTypeMapper.queryAllByCourseName(courseType.getCourseName());
        if (!CollectionUtils.isEmpty(courseTypes)) {
            return courseTypes.get(0);
        }
        this.courseTypeMapper.insert(courseType);
        return courseType;
    }

    /**
     * 修改数据
     *
     * @param courseType 实例对象
     * @return 实例对象
     */
    @Override
    public CourseType update(CourseType courseType) {
        this.courseTypeMapper.updateByPrimaryKeySelective(courseType);
        return this.queryById(courseType.getCourseTypeId());
    }

    /**
     * 通过主键删除数据
     *
     * @param courseTypeId 主键
     * @return 是否成功
     */
    @Override
    public boolean deleteById(Integer courseTypeId) {
        return this.courseTypeMapper.deleteByPrimaryKey(courseTypeId) > 0;
    }

    /**
     * 分页查询多条数据
     *
     * @param page 页码
     * @param size 查询条数
     * @return 对象列表
     */
    @Override
    public PageInfo queryAllByLimit(int page, int size) {
        return PageHelper.startPage(page, size).doSelectPageInfo(this.courseTypeMapper::selectAll);
    }
}