package com.hc.gpbusiness.service.impl;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.hc.gpbusiness.mapper.WebCourseTypeMapper;
import com.hc.gpbusiness.model.WebCourseType;
import com.hc.gpbusiness.service.WebCourseTypeService;
import org.springframework.stereotype.Service;

/**
 * 课程标签表(WebCourseType)表服务实现类
 *
 * @author java
 * @since 2020-07-29 16:23:09
 */

@Service("courseTypeService")
public class WebCourseTypeServiceImpl implements WebCourseTypeService {

    private final WebCourseTypeMapper courseTypeMapper;

    public WebCourseTypeServiceImpl(WebCourseTypeMapper courseTypeMapper) {
        this.courseTypeMapper = courseTypeMapper;
    }

    /**
     * 通过ID查询单条数据
     *
     * @param tagId 主键
     * @return 实例对象
     */
    @Override
    public WebCourseType queryById(Integer tagId) {
        return this.courseTypeMapper.selectByPrimaryKey(tagId);
    }

    /**
     * 新增数据
     *
     * @param courseType 实例对象
     * @return 实例对象
     */
    @Override
    public WebCourseType insert(WebCourseType courseType) {
        courseType.setCreateTime(System.currentTimeMillis());
        this.courseTypeMapper.insert(courseType);
        return courseType;
    }

    /**
     * 修改数据
     *
     * @param courseType 实例对象
     * @return 实例对象
     */
    @Override
    public WebCourseType update(WebCourseType courseType) {
        courseType.setUpdateTime(System.currentTimeMillis());
        this.courseTypeMapper.updateByPrimaryKeySelective(courseType);
        return this.queryById(courseType.getTypeId());
    }

    /**
     * 通过主键删除数据
     *
     * @param tagId 主键
     * @return 是否成功
     */
    @Override
    public boolean deleteById(Integer tagId) {
        return this.courseTypeMapper.deleteByPrimaryKey(tagId) > 0;
    }

    /**
     * 分页查询多条数据
     *
     * @param page 页码
     * @param size 查询条数
     * @return 对象列表
     */
    @Override
    public PageInfo queryAllByLimit(int page, int size) {
        return PageHelper.startPage(page, size).doSelectPageInfo(this.courseTypeMapper::selectAll);
    }
}