package com.hc.gpbusiness.service.impl;

import com.github.pagehelper.PageHelper;
import com.hc.gpbusiness.dto.WebModulesDto;
import com.hc.gpbusiness.mapper.WebModulesMapper;
import com.hc.gpbusiness.model.WebModules;
import com.hc.gpbusiness.service.WebModulesService;
import org.springframework.stereotype.Service;
import com.github.pagehelper.PageInfo;
import org.springframework.util.CollectionUtils;

import java.util.List;

/**
 * 板块表(Module)表服务实现类
 *
 * @author java
 * @since 2020-07-29 16:23:10
 */

@Service("moduleService")
public class WebModulesServiceImpl implements WebModulesService {

    private final WebModulesMapper moduleMapper;

    public WebModulesServiceImpl(WebModulesMapper moduleMapper) {
        this.moduleMapper = moduleMapper;
    }

    /**
     * 通过ID查询单条数据
     *
     * @param moduleId 主键
     * @return 实例对象
     */
    @Override
    public WebModules queryById(Integer moduleId) {
        return this.moduleMapper.selectByPrimaryKey(moduleId);
    }

    /**
     * 新增数据
     *
     * @param modules 实例对象
     * @return 实例对象
     */
    @Override
    public WebModules insert(WebModules modules) {
        modules.setCreateTime(System.currentTimeMillis());
        this.moduleMapper.insert(modules);
        return modules;
    }

    /**
     * 修改数据
     *
     * @param modules 实例对象
     * @return 实例对象
     */
    @Override
    public WebModules update(WebModules modules) {
        modules.setUpdateTime(System.currentTimeMillis());
        this.moduleMapper.updateByPrimaryKeySelective(modules);
        return this.queryById(modules.getModuleId());
    }

    /**
     * 通过主键删除数据
     *
     * @param moduleId 主键
     * @return 是否成功
     */
    @Override
    public boolean deleteById(Integer moduleId) {
        return this.moduleMapper.deleteByPrimaryKey(moduleId) > 0;
    }

    /**
     * 分页查询多条数据
     *
     * @param page 页码
     * @param size 查询条数
     * @return 对象列表
     */
    @Override
    public PageInfo queryAllByLimit(int page, int size) {
        PageHelper.startPage(page, size);
        List<WebModulesDto> moduless = this.moduleMapper.queryByParentId(0);
        if (CollectionUtils.isEmpty(moduless)) {
            return null;
        }
        moduless.forEach(modulesDto -> modulesDto.setChildModuleType(this.moduleMapper.queryByParentId(modulesDto.getModuleId())));
        return new PageInfo(moduless);
    }
}