package com.hc.gpbusiness.service.impl;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.hc.gpbusiness.mapper.WebNewsTypeMapper;
import com.hc.gpbusiness.model.WebNewsType;
import com.hc.gpbusiness.service.WebNewsTypeService;
import org.springframework.stereotype.Service;

/**
 * 课程标签表(WebNewsType)表服务实现类
 *
 * @author java
 * @since 2020-07-29 16:23:09
 */

@Service("newsTypeService")
public class WebNewsTypeServiceImpl implements WebNewsTypeService {

    private final WebNewsTypeMapper newsTypeMapper;

    public WebNewsTypeServiceImpl(WebNewsTypeMapper newsTypeMapper) {
        this.newsTypeMapper = newsTypeMapper;
    }

    /**
     * 通过ID查询单条数据
     *
     * @param tagId 主键
     * @return 实例对象
     */
    @Override
    public WebNewsType queryById(Integer tagId) {
        return this.newsTypeMapper.selectByPrimaryKey(tagId);
    }

    /**
     * 新增数据
     *
     * @param newsType 实例对象
     * @return 实例对象
     */
    @Override
    public WebNewsType insert(WebNewsType newsType) {
        newsType.setCreateTime(System.currentTimeMillis());
        this.newsTypeMapper.insert(newsType);
        return newsType;
    }

    /**
     * 修改数据
     *
     * @param newsType 实例对象
     * @return 实例对象
     */
    @Override
    public WebNewsType update(WebNewsType newsType) {
        newsType.setUpdateTime(System.currentTimeMillis());
        this.newsTypeMapper.updateByPrimaryKeySelective(newsType);
        return this.queryById(newsType.getTypeId());
    }

    /**
     * 通过主键删除数据
     *
     * @param tagId 主键
     * @return 是否成功
     */
    @Override
    public boolean deleteById(Integer tagId) {
        return this.newsTypeMapper.deleteByPrimaryKey(tagId) > 0;
    }

    /**
     * 分页查询多条数据
     *
     * @param page 页码
     * @param size 查询条数
     * @return 对象列表
     */
    @Override
    public PageInfo queryAllByLimit(int page, int size) {
        return PageHelper.startPage(page, size).doSelectPageInfo(this.newsTypeMapper::selectAll);
    }
}