package com.hc.business.service;

import com.github.pagehelper.PageInfo;
import com.hc.business.model.ZccmUserInvoices;
import org.springframework.stereotype.Component;

import java.util.List;


/**
 * 用户发票表(ZccmUserInvoices)表服务接口
 *
 * @author java
 * @since 2020-12-02 10:50:36
 */

@Component
public interface ZccmUserInvoicesService {

    /**
     * 通过ID查询单条数据
     *
     * @param userInvoicesId 主键
     * @return 实例对象
     */
    ZccmUserInvoices queryById(Integer userInvoicesId);

    /**
     * 新增数据
     *
     * @param userInvoices 实例对象
     * @return 实例对象
     */
    ZccmUserInvoices insert(ZccmUserInvoices userInvoices);

    /**
     * 修改数据
     *
     * @param userInvoices 实例对象
     * @return 实例对象
     */
    ZccmUserInvoices update(ZccmUserInvoices userInvoices);

    /**
     * 通过主键删除数据
     *
     * @param userInvoicesId 主键
     * @return 是否成功
     */
    boolean deleteById(Integer userInvoicesId);

    /**
     * 分页查询多条数据
     *
     * @param page 页码
     * @param size 查询条数
     * @return 对象列表
     */
    PageInfo queryAllByLimit(int page, int size);

    /**
     * 获取用户的发票信息
     *
     * @param userId 用户id
     * @return 实例对象数组
     */
    List<ZccmUserInvoices> queryDetailByUserId(Integer userId);

    /**
     * 获取班次发票信息
     *
     * @param classId 班次id
     * @return 实例对象数组
     */
    List<ZccmUserInvoices> queryByClassId(Integer classId);

    /**
     * 获取状态获取发票信息
     *
     * @param status 状态
     * @return 实例对象数组
     */
    List<ZccmUserInvoices> queryByStatus(Integer status);


}